@@ -71,7 +71,7 @@ class Orientation:
 
         for geom in tqdm(gdf.geometry, total=gdf.shape[0], disable=not verbose):
             if geom.type in ["Polygon", "MultiPolygon", "LinearRing"]:
-                # TODO: vectorize once minimum_rotated_rectangle is in geopandas from pygeos
+                # TODO: vectorize once minimum_rotated_rectangle is in geopandas
                 bbox = list(geom.minimum_rotated_rectangle.exterior.coords)
                 axis1 = _dist(bbox[0], bbox[3])
                 axis2 = _dist(bbox[0], bbox[1])
@@ -85,6 +85,7 @@ class Orientation:
                 az = _azimuth(coords[0], coords[-1])
             else:
                 results_list.append(np.nan)
+                continue
 
             if 90 > az >= 45:
                 diff = az - 45
@@ -171,7 +172,8 @@ class SharedWallsRatio(SharedWalls):
     gdf : GeoDataFrame
         GeoDataFrame containing gdf to analyse
     perimeters : str, list, np.array, pd.Series (default None, optional)
-        the name of the dataframe column, ``np.array``, or ``pd.Series`` where is stored perimeter value
+        the name of the dataframe column, ``np.array``, or ``pd.Series`` where is
+        stored perimeter value
 
     Attributes
     ----------
@@ -208,12 +210,15 @@ class SharedWallsRatio(SharedWalls):
 
 class StreetAlignment:
     """
-    Calculate the difference between street orientation and orientation of object in degrees
+    Calculate the difference between street orientation and orientation of object in
+    degrees
 
     Orientation of street segment is represented by the orientation of line
     connecting first and last point of the segment. Network ID linking each object
-    to specific street segment is needed. Can be generated by :func:`momepy.get_network_id`.
-    Either ``network_id`` or both ``left_network_id`` and ``right_network_id`` are required.
+    to specific street segment is needed. Can be generated by
+    :func:`momepy.get_network_id`.
+    Either ``network_id`` or both ``left_network_id`` and ``right_network_id``
+    are required.
 
     .. math::
         \\left|{\\textit{building orientation} - \\textit{street orientation}}\\right|
@@ -225,14 +230,17 @@ class StreetAlignment:
     right : GeoDataFrame
         GeoDataFrame containing street network
     orientations : str, list, np.array, pd.Series
-        the name of the dataframe column, ``np.array``, or ``pd.Series`` where is stored object orientation value
+        the name of the dataframe column, ``np.array``, or ``pd.Series`` where is
+        stored object orientation value
         (can be calculated using :class:`momepy.Orientation`)
     network_id : str (default None)
         the name of the column storing network ID in both left and right
     left_network_id : str, list, np.array, pd.Series (default None)
-        the name of the left dataframe column, ``np.array``, or ``pd.Series`` where is stored object network ID
+        the name of the left dataframe column, ``np.array``, or ``pd.Series`` where is
+        stored object network ID
     right_network_id : str, list, np.array, pd.Series (default None)
-        the name of the right dataframe column, ``np.array``, or ``pd.Series`` of streets with unique network id (has to be defined beforehand)
+        the name of the right dataframe column, ``np.array``, or ``pd.Series`` of
+        streets with unique network id (has to be defined beforehand)
         (can be defined using :func:`momepy.unique_id`)
 
     Attributes
@@ -252,7 +260,11 @@ class StreetAlignment:
 
     Examples
     --------
-    >>> buildings_df['street_alignment'] = momepy.StreetAlignment(buildings_df, streets_df, 'orientation', 'nID', 'nID').series
+    >>> buildings_df['street_alignment'] = momepy.StreetAlignment(buildings_df,
+    ...                                                           streets_df,
+    ...                                                           'orientation',
+    ...                                                           'nID',
+    ...                                                           'nID').series
     >>> buildings_df['street_alignment'][0]
     0.29073888476702336
     """
@@ -283,7 +295,8 @@ class StreetAlignment:
                 raise ValueError("right_network_id not set.")
             if left_network_id is None and right_network_id is None:
                 raise ValueError(
-                    "Network ID not set. Use either network_id or left_network_id and right_network_id."
+                    "Network ID not set. Use either network_id or left_network_id "
+                    "and right_network_id."
                 )
 
         if not isinstance(orientations, str):
@@ -326,15 +339,19 @@ class CellAlignment:
     right : GeoDataFrame
         GeoDataFrame containing tessellation cells (or relevant spatial units)
     left_orientations : str, list, np.array, pd.Series
-        the name of the left dataframe column, ``np.array``, or ``pd.Series`` where is stored object orientation value
+        the name of the left dataframe column, ``np.array``, or ``pd.Series`` where is
+        stored object orientation value
         (can be calculated using :class:`momepy.Orientation`)
     right_orientations : str, list, np.array, pd.Series
-        the name of the right dataframe column, ``np.array``, or ``pd.Series`` where is stored object orientation value
+        the name of the right dataframe column, ``np.array``, or ``pd.Series`` where is
+        stored object orientation value
         (can be calculated using :class:`momepy.Orientation`)
     left_unique_id : str
-        the name of the ``left`` dataframe column with unique id shared between ``left`` and ``right`` gdf
+        the name of the ``left`` dataframe column with unique id shared between ``left``
+         and ``right`` gdf
     right_unique_id : str
-        the name of the ``right`` dataframe column with unique id shared between ``left`` and ``right`` gdf
+        the name of the ``right`` dataframe column with unique id shared between
+        ``left`` and ``right`` gdf
 
     Attributes
     ----------
@@ -355,7 +372,12 @@ class CellAlignment:
 
     Examples
     --------
-    >>> buildings_df['cell_alignment'] = momepy.CellAlignment(buildings_df, tessellation_df, 'bl_orient', 'tes_orient', 'uID', 'uID').series
+    >>> buildings_df['cell_alignment'] = momepy.CellAlignment(buildings_df,
+    ...                                                       tessellation_df,
+    ...                                                       'bl_orient',
+    ...                                                       'tes_orient',
+    ...                                                       'uID',
+    ...                                                       'uID').series
     >>> buildings_df['cell_alignment'][0]
     0.8795123936951939
 
@@ -402,7 +424,8 @@ class CellAlignment:
 class Alignment:
 
     """
-    Calculate the mean deviation of solar orientation of objects on adjacent cells from an object
+    Calculate the mean deviation of solar orientation of objects on adjacent cells
+    from an object
 
     .. math::
         \\frac{1}{n}\\sum_{i=1}^n dev_i=\\frac{dev_1+dev_2+\\cdots+dev_n}{n}
@@ -414,7 +437,8 @@ class Alignment:
     spatial_weights : libpysal.weights, optional
         spatial weights matrix
     orientations : str, list, np.array, pd.Series
-        the name of the left dataframe column, ``np.array``, or ``pd.Series`` where is stored object orientation value
+        the name of the left dataframe column, ``np.array``, or ``pd.Series`` where is
+        stored object orientation value
         (can be calculated using :class:`momepy.Orientation`)
     unique_id : str
         name of the column with unique id used as ``spatial_weights`` index.
@@ -436,7 +460,10 @@ class Alignment:
 
     Examples
     --------
-    >>> buildings_df['alignment'] = momepy.Alignment(buildings_df, sw, 'uID', bl_orient).series
+    >>> buildings_df['alignment'] = momepy.Alignment(buildings_df,
+    ...                                              sw,
+    ...                                              'uID',
+    ...                                              bl_orient).series
     100%|██████████| 144/144 [00:01<00:00, 140.84it/s]
     >>> buildings_df['alignment'][0]
     18.299481296455237
@@ -509,7 +536,9 @@ class NeighborDistance:
 
     Examples
     --------
-    >>> buildings_df['neighbour_distance'] = momepy.NeighborDistance(buildings_df, sw, 'uID').series
+    >>> buildings_df['neighbour_distance'] = momepy.NeighborDistance(buildings_df,
+    ...                                                              sw,
+    ...                                                              'uID').series
     100%|██████████| 144/144 [00:00<00:00, 345.78it/s]
     >>> buildings_df['neighbour_distance'][0]
     29.18589019096464
@@ -587,7 +616,11 @@ class MeanInterbuildingDistance:
 
     Examples
     --------
-    >>> buildings_df['mean_interbuilding_distance'] = momepy.MeanInterbuildingDistance(buildings_df, sw, 'uID').series
+    >>> buildings_df['mean_interbuilding_distance'] = momepy.MeanInterbuildingDistance(
+    ...     buildings_df,
+    ...     sw,
+    ...     'uID'
+    ... ).series
     Computing mean interbuilding distances...
     100%|██████████| 144/144 [00:00<00:00, 317.42it/s]
     >>> buildings_df['mean_interbuilding_distance'][0]
@@ -665,7 +698,9 @@ class NeighboringStreetOrientationDeviation:
 
     Examples
     --------
-    >>> streets_df['orient_dev'] = momepy.NeighboringStreetOrientationDeviation(streets_df).series
+    >>> streets_df['orient_dev'] = momepy.NeighboringStreetOrientationDeviation(
+    ...     streets_df
+    ... ).series
     >>> streets_df['orient_dev'][6]
     7.043096518688273
     """
@@ -716,7 +751,8 @@ class BuildingAdjacency:
     """
     Calculate the level of building adjacency
 
-    Building adjacency reflects how much buildings tend to join together into larger structures.
+    Building adjacency reflects how much buildings tend to join together into larger
+    structures.
     It is calculated as a ratio of joined built-up structures and buildings within
     the extent defined in ``spatial_weights_higher``.
 
@@ -751,7 +787,9 @@ class BuildingAdjacency:
 
     Examples
     --------
-    >>> buildings_df['adjacency'] = momepy.BuildingAdjacency(buildings_df, swh, unique_id='uID').series
+    >>> buildings_df['adjacency'] = momepy.BuildingAdjacency(buildings_df,
+    ...                                                      swh,
+    ...                                                      unique_id='uID').series
     Calculating spatial weights...
     Spatial weights ready...
     Calculating adjacency: 100%|██████████| 144/144 [00:00<00:00, 335.55it/s]
@@ -807,8 +845,8 @@ class Neighbors:
     """
     Calculate the number of neighbours captured by ``spatial_weights``
 
-    If ``weighted=True``, number of neighbours will be divided by the perimeter of object
-    to return relative value.
+    If ``weighted=True``, number of neighbours will be divided by the perimeter of
+    object to return relative value.
 
     Adapted from :cite:`hermosilla2012`.
 
@@ -822,7 +860,8 @@ class Neighbors:
     unique_id : str
         name of the column with unique id used as ``spatial_weights`` index
     weighted : bool (default False)
-        if ``True``, number of neighbours will be divided by the perimeter of object, to return relative value
+        if ``True``, number of neighbours will be divided by the perimeter of object,
+        to return relative value
     verbose : bool (default True)
         if True, shows progress bars in loops and indication of steps
 
@@ -843,8 +882,11 @@ class Neighbors:
 
     Examples
     --------
-    >>> sw = libpysal.weights.contiguity.Queen.from_dataframe(tessellation_df, ids='uID')
-    >>> tessellation_df['neighbours'] = momepy.Neighbors(tessellation_df, sw, 'uID').series
+    >>> sw = libpysal.weights.contiguity.Queen.from_dataframe(tessellation_df,
+    ...                                                       ids='uID')
+    >>> tessellation_df['neighbours'] = momepy.Neighbors(tessellation_df,
+    ...                                                  sw,
+    ...                                                  'uID').series
     100%|██████████| 144/144 [00:00<00:00, 6909.50it/s]
     >>> tessellation_df['neighbours'][0]
     4
